# Modélisation d'épidémies

**Avertissement:** Dans cette brève introduction nous n'avons pas la prétention
de présenter des modèles très précis ayant une grande valeur prédictive.
L'objectif est plutôt de se familiariser avec le concept de modèle mathématique
ainsi que d'étudier un modèle simplifié de propagation d'épidémieet de voir quels peuvent
être les effets de la quarantaine sur une propagation libre.

## L'exponentielle

Un modèle mathématique d'une épidémie est une abstraction mathématique de la réalité permettant
de faire des prédictions sur l'évolution du nombre de personne atteinte et leur guérison possible
guérison. Elle permet ainsi de prévoir l'effet des politiques publiques pour contenir
les épidémies: quarantaine, vaccination, ...

Imaginons d'abord un modèle très simple où nous considérons une fonction, $M(t)$, 
qui donne le nombre nombre d'individus ayant contracté une maladie en fonction
du temps. La valeur $M_0=M(0)$ est le nombre de malades le jour où la maladie
se déclare pour la première fois. On aimerait décrire l'évolution
de cette maladie. Pour ce faire, nous allons écrire une équation
qui va représenter le taux de variation de $M(t)$, soit $M'(t)$, la dérivée de $M(t)$.

Supposons dans notre modèle très simplifié, que chaque personne malade
contamine exactement deux personnes saines en un temps $\delta t$. 
Supposons également qu'il y a une infinité
de personnes saines (c'est pas très réaliste mais cela simplifie les choses pour le moment).
Nous avons donc que le nombre de personne infectées au temps $t+\delta t$, $M(t+\delta t)$
est donné par
$$
M(t+\delta t)=M(t)+\delta t \cdot 2\cdot M(t).
$$
A gauche de cette équation nous avons le nombre de malades au temps $t+\delta t$ qui
est donné par le nombre de malade le jour $t$, auquel on additionne le nombre de nouveaux malades
qu'ils ont contaminés en une journée (2 fois leur nombre).

Si $\delta t$ est un jour, et que nous avons au premier jour une seul malade, $M(0)=1$,
on a la suite suivante
\begin{align}
M(0)&=1\mbox{ malades},\\
M(1)&=M(0)+1\cdot 2 M(0)=1 + 2=3\mbox{ malades},\\
M(2)&=M(1)+1\cdot 2 M(1)=3 + 6=9\mbox{ malades},\\
M(3)&=M(2)+1\cdot 2 M(2)=9 + 18=27\mbox{ malades},\\
\vdots&
\end{align}
On peut facilement se convainque qu'au bout de $n$ jours, le
nombre de malades a atteint $3^n$. On a une croissance **exponentielle**
du nombre de malades.

Ce qu'on a fait ici comme modèle est un modèle compartimental (on a compartimenté la population):
on a divisé la population en une classe, celle des malades $M(t)$. Puis
on a adjoint une règle d'évolution à cette classe: chaque jour chaque malade infecte
deux nouvelles personnes. Ce modèle est très simpliste mais il illustre très bien
comment on constuit un modèle d'épidémie.

Par ailleurs, on peut se rendre compte que l'équation que nous avons écrite plus
haut décrit l'évolution du *taux de variation* de $M(t)$. En effet, en réarrangeant les termes de cette équation, on a que
$$
\underbrace{\frac{M(t+\delta t)-M(t)}{\delta t}}_{\mbox{taux de variation}}=2M(t).
$$
Si nous prenons la limite pour $\delta t\rightarrow 0$ des deux côtés
nous obtenons
$$
M'(t)=2M(t).
$$
Ceci est une **équation différentielle**, une équation dont l'inconnue est une fonction
et qui relie sa forme avec ses dérivées. Nous allons utiliser
ce type d'équations pour voir un modèle un peu plus réaliste de modèle
d'épidémies dans la section suivante.

## Modèles compartimentaux

Les modèles compartimentaux, créés autour des années 1920, sont des modèles
mathématiques permettant de représenter la propagation des épidémies.
Ces modèles divisent une population en plusieurs *classes* épidémiologiques (compartiments)
comme les individus sains mais susceptibles d'être infectés, les individus infectieux, et
les individus guéris (qui ont acquis une immunité suite à une infection). Ces trois compartiements
sont notés respectivement, $S$, $I$, et $R$. Il en existe d'autres, mais nous ne les
discuterons pas dans le cadre de cette petite introduction.

Une fois les compartiments définis, il est nécessaire de définir les *règles* permettant de passer d'un compartiment à l'autre. Dans le cas à trois classes ci-dessus, nous voulons
décrire les transitions entre les patients sains (susceptibles d'attraper la maladie) et inféctieux,
$$
S\rightarrow I,
$$
puis entre infectieux et guéris
$$
S\rightarrow I.
$$

La transition $S\rightarrow I$ est décrite par le taux de transmission de la maladie, $\beta\cdot I$. $\beta$ est le nombre de contacts par personne multipliée par la probabilité de transmission de la maladie quand une personne infectieuse rencontre une personne susceptible d'attraper la malade.

De même la transition $I\rightarrow R$ est donnée par $\lambda=1/d$, le taux de guérison (ou de mort) qui est simplement
l'inverse du temps nécessaire à la guérison (ou à la mort).






